Core
----

caspo.core.setup
^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.setup
    :members:
    
caspo.core.literal
^^^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.literal
    :members:
    
caspo.core.clamping
^^^^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.clamping
    :members:


caspo.core.dataset
^^^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.dataset
    :members:

caspo.core.graph
^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.graph
    :members:

caspo.core.hypergraph
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.hypergraph
    :members:

caspo.core.mapping
^^^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.mapping
    :members:

caspo.core.clause
^^^^^^^^^^^^^^^^^

.. automodule:: caspo.core.clause
    :members:

caspo.core.logicalnetwork
^^^^^^^^^^^^^^^^^^^^^^^^^
    
.. automodule:: caspo.core.logicalnetwork
    :members:
